# Rust API client for mithril-client

Mithril Compute API


## Overview

This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [openapi-spec](https://openapis.org) from a remote server, you can easily generate an API client.

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.19.0
- Build package: `org.openapitools.codegen.languages.RustClientCodegen`

## Installation

Put the package under your project folder in a directory named `mithril-client` and add the following to `Cargo.toml` under `[dependencies]`:

```
mithril-client = { path = "./mithril-client" }
```

## Documentation for API Endpoints

All URIs are relative to *https://api.mithril.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApiKeysApi* | [**create_api_key_v2_api_keys_post**](docs/ApiKeysApi.md#create_api_key_v2_api_keys_post) | **POST** /v2/api-keys | Create Api Key
*ApiKeysApi* | [**get_api_keys_v2_api_keys_get**](docs/ApiKeysApi.md#get_api_keys_v2_api_keys_get) | **GET** /v2/api-keys | Get Api Keys
*ApiKeysApi* | [**revoke_api_key_v2_api_keys_key_fid_delete**](docs/ApiKeysApi.md#revoke_api_key_v2_api_keys_key_fid_delete) | **DELETE** /v2/api-keys/{key_fid} | Revoke Api Key
*ImageVersionsApi* | [**get_image_versions_v2_image_versions_get**](docs/ImageVersionsApi.md#get_image_versions_v2_image_versions_get) | **GET** /v2/image-versions | Get Image Versions
*ImageVersionsApi* | [**get_mcc_image_versions_v2_mcc_image_versions_get**](docs/ImageVersionsApi.md#get_mcc_image_versions_v2_mcc_image_versions_get) | **GET** /v2/mcc-image-versions | Get Mcc Image Versions
*InstanceTypesApi* | [**get_instance_types_v2_instance_types_get**](docs/InstanceTypesApi.md#get_instance_types_v2_instance_types_get) | **GET** /v2/instance-types | Get Instance Types
*InstancesApi* | [**get_instance_status_v2_instances_instance_id_status_get**](docs/InstancesApi.md#get_instance_status_v2_instances_instance_id_status_get) | **GET** /v2/instances/{instance_id}/status | Get Instance Status
*InstancesApi* | [**get_instances_v2_instances_get**](docs/InstancesApi.md#get_instances_v2_instances_get) | **GET** /v2/instances | Get Instances
*KubernetesClustersApi* | [**create_kubernetes_cluster_v2_kubernetes_clusters_post**](docs/KubernetesClustersApi.md#create_kubernetes_cluster_v2_kubernetes_clusters_post) | **POST** /v2/kubernetes/clusters | Create Kubernetes Cluster
*KubernetesClustersApi* | [**delete_kubernetes_cluster_v2_kubernetes_clusters_cluster_fid_delete**](docs/KubernetesClustersApi.md#delete_kubernetes_cluster_v2_kubernetes_clusters_cluster_fid_delete) | **DELETE** /v2/kubernetes/clusters/{cluster_fid} | Delete Kubernetes Cluster
*KubernetesClustersApi* | [**get_kubernetes_cluster_v2_kubernetes_clusters_cluster_fid_get**](docs/KubernetesClustersApi.md#get_kubernetes_cluster_v2_kubernetes_clusters_cluster_fid_get) | **GET** /v2/kubernetes/clusters/{cluster_fid} | Get Kubernetes Cluster
*KubernetesClustersApi* | [**get_kubernetes_clusters_v2_kubernetes_clusters_get**](docs/KubernetesClustersApi.md#get_kubernetes_clusters_v2_kubernetes_clusters_get) | **GET** /v2/kubernetes/clusters | Get Kubernetes Clusters
*LifecycleScriptsApi* | [**create_lifecycle_script_v2_lifecycle_scripts_post**](docs/LifecycleScriptsApi.md#create_lifecycle_script_v2_lifecycle_scripts_post) | **POST** /v2/lifecycle-scripts | Create Lifecycle Script
*LifecycleScriptsApi* | [**delete_lifecycle_script_v2_lifecycle_scripts_ls_fid_delete**](docs/LifecycleScriptsApi.md#delete_lifecycle_script_v2_lifecycle_scripts_ls_fid_delete) | **DELETE** /v2/lifecycle-scripts/{ls_fid} | Delete Lifecycle Script
*LifecycleScriptsApi* | [**get_lifecycle_script_content_v2_lifecycle_scripts_ls_fid_content_get**](docs/LifecycleScriptsApi.md#get_lifecycle_script_content_v2_lifecycle_scripts_ls_fid_content_get) | **GET** /v2/lifecycle-scripts/{ls_fid}/content | Get Lifecycle Script Content
*LifecycleScriptsApi* | [**list_lifecycle_scripts_v2_lifecycle_scripts_get**](docs/LifecycleScriptsApi.md#list_lifecycle_scripts_v2_lifecycle_scripts_get) | **GET** /v2/lifecycle-scripts | List Lifecycle Scripts
*LifecycleScriptsApi* | [**update_lifecycle_script_v2_lifecycle_scripts_ls_fid_patch**](docs/LifecycleScriptsApi.md#update_lifecycle_script_v2_lifecycle_scripts_ls_fid_patch) | **PATCH** /v2/lifecycle-scripts/{ls_fid} | Update Lifecycle Script
*PricingApi* | [**get_current_prices_v2_v2_pricing_current_get**](docs/PricingApi.md#get_current_prices_v2_v2_pricing_current_get) | **GET** /v2/pricing/current | Get Current Prices V2
*PricingApi* | [**get_historical_prices_v2_v2_pricing_history_get**](docs/PricingApi.md#get_historical_prices_v2_v2_pricing_history_get) | **GET** /v2/pricing/history | Get Historical Prices V2
*ProfileApi* | [**get_me_v2_me_get**](docs/ProfileApi.md#get_me_v2_me_get) | **GET** /v2/me | Get Me
*ProfileApi* | [**get_my_teammates_v2_me_teammates_get**](docs/ProfileApi.md#get_my_teammates_v2_me_teammates_get) | **GET** /v2/me/teammates | Get My Teammates
*ProjectsApi* | [**get_projects_v2_projects_get**](docs/ProjectsApi.md#get_projects_v2_projects_get) | **GET** /v2/projects | Get Projects
*QuotasApi* | [**get_quotas_v2_quotas_get**](docs/QuotasApi.md#get_quotas_v2_quotas_get) | **GET** /v2/quotas | Get Quotas
*ReservationsApi* | [**create_reservation_v2_reservation_post**](docs/ReservationsApi.md#create_reservation_v2_reservation_post) | **POST** /v2/reservation | Create Reservation
*ReservationsApi* | [**extend_reservation_v2_reservation_reservation_fid_extend_post**](docs/ReservationsApi.md#extend_reservation_v2_reservation_reservation_fid_extend_post) | **POST** /v2/reservation/{reservation_fid}/extend | Extend Reservation
*ReservationsApi* | [**get_availability_v2_reservation_availability_get**](docs/ReservationsApi.md#get_availability_v2_reservation_availability_get) | **GET** /v2/reservation/availability | Get Availability
*ReservationsApi* | [**get_extension_availability_v2_reservation_reservation_fid_extension_availability_get**](docs/ReservationsApi.md#get_extension_availability_v2_reservation_reservation_fid_extension_availability_get) | **GET** /v2/reservation/{reservation_fid}/extension-availability | Get Extension Availability
*ReservationsApi* | [**get_reservations_v2_reservation_get**](docs/ReservationsApi.md#get_reservations_v2_reservation_get) | **GET** /v2/reservation | Get Reservations
*ReservationsApi* | [**update_reservation_v2_reservation_reservation_fid_patch**](docs/ReservationsApi.md#update_reservation_v2_reservation_reservation_fid_patch) | **PATCH** /v2/reservation/{reservation_fid} | Update Reservation
*SshKeysApi* | [**create_ssh_key_v2_ssh_keys_post**](docs/SshKeysApi.md#create_ssh_key_v2_ssh_keys_post) | **POST** /v2/ssh-keys | Create Ssh Key
*SshKeysApi* | [**delete_ssh_key_v2_ssh_keys_ssh_key_fid_delete**](docs/SshKeysApi.md#delete_ssh_key_v2_ssh_keys_ssh_key_fid_delete) | **DELETE** /v2/ssh-keys/{ssh_key_fid} | Delete Ssh Key
*SshKeysApi* | [**get_ssh_keys_v2_ssh_keys_get**](docs/SshKeysApi.md#get_ssh_keys_v2_ssh_keys_get) | **GET** /v2/ssh-keys | Get Ssh Keys
*SshKeysApi* | [**update_ssh_key_v2_ssh_keys_ssh_key_fid_patch**](docs/SshKeysApi.md#update_ssh_key_v2_ssh_keys_ssh_key_fid_patch) | **PATCH** /v2/ssh-keys/{ssh_key_fid} | Update Ssh Key
*SpotApi* | [**cancel_bid_v2_spot_bids_bid_fid_delete**](docs/SpotApi.md#cancel_bid_v2_spot_bids_bid_fid_delete) | **DELETE** /v2/spot/bids/{bid_fid} | Cancel Bid
*SpotApi* | [**create_bid_v2_spot_bids_post**](docs/SpotApi.md#create_bid_v2_spot_bids_post) | **POST** /v2/spot/bids | Create Bid
*SpotApi* | [**get_auctions_v2_spot_availability_get**](docs/SpotApi.md#get_auctions_v2_spot_availability_get) | **GET** /v2/spot/availability | Get Auctions
*SpotApi* | [**get_bid_history_v2_spot_bids_bid_fid_history_get**](docs/SpotApi.md#get_bid_history_v2_spot_bids_bid_fid_history_get) | **GET** /v2/spot/bids/{bid_fid}/history | Get Bid History
*SpotApi* | [**get_bid_status_v2_spot_bids_bid_fid_status_get**](docs/SpotApi.md#get_bid_status_v2_spot_bids_bid_fid_status_get) | **GET** /v2/spot/bids/{bid_fid}/status | Get Bid Status
*SpotApi* | [**get_bid_v2_spot_bids_bid_fid_get**](docs/SpotApi.md#get_bid_v2_spot_bids_bid_fid_get) | **GET** /v2/spot/bids/{bid_fid} | Get Bid
*SpotApi* | [**get_bids_v2_spot_bids_get**](docs/SpotApi.md#get_bids_v2_spot_bids_get) | **GET** /v2/spot/bids | Get Bids
*SpotApi* | [**update_bid_v2_spot_bids_bid_fid_patch**](docs/SpotApi.md#update_bid_v2_spot_bids_bid_fid_patch) | **PATCH** /v2/spot/bids/{bid_fid} | Update Bid
*VolumesApi* | [**create_volume_v2_volumes_post**](docs/VolumesApi.md#create_volume_v2_volumes_post) | **POST** /v2/volumes | Create Volume
*VolumesApi* | [**delete_volume_v2_volumes_volume_fid_delete**](docs/VolumesApi.md#delete_volume_v2_volumes_volume_fid_delete) | **DELETE** /v2/volumes/{volume_fid} | Delete Volume
*VolumesApi* | [**get_volumes_v2_volumes_get**](docs/VolumesApi.md#get_volumes_v2_volumes_get) | **GET** /v2/volumes | Get Volumes
*VolumesApi* | [**update_volume_v2_volumes_volume_fid_patch**](docs/VolumesApi.md#update_volume_v2_volumes_volume_fid_patch) | **PATCH** /v2/volumes/{volume_fid} | Update Volume


## Documentation For Models

 - [ApiKeyModel](docs/ApiKeyModel.md)
 - [AuctionModel](docs/AuctionModel.md)
 - [AvailabilitySlotModel](docs/AvailabilitySlotModel.md)
 - [BidHistoryEventModel](docs/BidHistoryEventModel.md)
 - [BidHistoryResponse](docs/BidHistoryResponse.md)
 - [BidModel](docs/BidModel.md)
 - [BidStatusResponse](docs/BidStatusResponse.md)
 - [CheckAvailabilityResponse](docs/CheckAvailabilityResponse.md)
 - [CreateApiKeyRequest](docs/CreateApiKeyRequest.md)
 - [CreateApiKeyResponse](docs/CreateApiKeyResponse.md)
 - [CreateBidRequest](docs/CreateBidRequest.md)
 - [CreateKubernetesClusterRequest](docs/CreateKubernetesClusterRequest.md)
 - [CreateLifecycleScriptRequest](docs/CreateLifecycleScriptRequest.md)
 - [CreateReservationRequest](docs/CreateReservationRequest.md)
 - [CreateSshKeyRequest](docs/CreateSshKeyRequest.md)
 - [CreateVolumeRequest](docs/CreateVolumeRequest.md)
 - [CreatedSshKeyModel](docs/CreatedSshKeyModel.md)
 - [CurrentPricesResponse](docs/CurrentPricesResponse.md)
 - [ExtendReservationRequest](docs/ExtendReservationRequest.md)
 - [ExtensionAvailabilityResponse](docs/ExtensionAvailabilityResponse.md)
 - [GetBidsResponse](docs/GetBidsResponse.md)
 - [GetInstancesResponse](docs/GetInstancesResponse.md)
 - [GetLatestEndTimeResponse](docs/GetLatestEndTimeResponse.md)
 - [GetReservationsResponse](docs/GetReservationsResponse.md)
 - [HistoricalPricePointModel](docs/HistoricalPricePointModel.md)
 - [HistoricalPricesResponseModel](docs/HistoricalPricesResponseModel.md)
 - [HttpValidationError](docs/HttpValidationError.md)
 - [ImageVersionModel](docs/ImageVersionModel.md)
 - [InstanceModel](docs/InstanceModel.md)
 - [InstanceStatusResponse](docs/InstanceStatusResponse.md)
 - [InstanceTypeModel](docs/InstanceTypeModel.md)
 - [KubernetesClusterModel](docs/KubernetesClusterModel.md)
 - [LaunchSpecificationModel](docs/LaunchSpecificationModel.md)
 - [LifecycleScriptModel](docs/LifecycleScriptModel.md)
 - [LifecycleScriptScope](docs/LifecycleScriptScope.md)
 - [ListLifecycleScriptsResponse](docs/ListLifecycleScriptsResponse.md)
 - [LocationInner](docs/LocationInner.md)
 - [MeResponse](docs/MeResponse.md)
 - [NewSshKeyModel](docs/NewSshKeyModel.md)
 - [PersistentDiskChange](docs/PersistentDiskChange.md)
 - [ProjectModel](docs/ProjectModel.md)
 - [PublicLifecycleScriptScope](docs/PublicLifecycleScriptScope.md)
 - [QuotaModel](docs/QuotaModel.md)
 - [ReservationModel](docs/ReservationModel.md)
 - [Size](docs/Size.md)
 - [SizeUnit](docs/SizeUnit.md)
 - [SortDirection](docs/SortDirection.md)
 - [TeammateResponse](docs/TeammateResponse.md)
 - [UpdateBidRequest](docs/UpdateBidRequest.md)
 - [UpdateLifecycleScriptRequest](docs/UpdateLifecycleScriptRequest.md)
 - [UpdateReservationRequest](docs/UpdateReservationRequest.md)
 - [UpdateSshKeyRequest](docs/UpdateSshKeyRequest.md)
 - [UpdateVolumeRequest](docs/UpdateVolumeRequest.md)
 - [ValidationError](docs/ValidationError.md)
 - [VolumeModel](docs/VolumeModel.md)


To get access to the crate's generated documentation, use:

```
cargo doc --open
```

## Author



